@@ -18,5 +18,11 @@ class FAQEntry(models.Model):
 class FAQPlugin(CMSPlugin):
     faq_list = models.ForeignKey(FAQList)
 
+    def copy_relations(self, oldinstance):
+        self.faq_list = oldinstance.faq_list
+
+class FAQListPlugin(CMSPlugin):
+    faq_list = models.ManyToManyField(FAQList)
+
     def copy_relations(self, oldinstance):
         self.faq_list = oldinstance.faq_list
\ No newline at end of file
